#ifdef TURBO                  /* Turbo C users be sure you define */
#include <alloc.h>            /* TURBO on the command line.       */
#else
#include <malloc.h>
#endif

#include <stdio.h>
#include <dos.h>
#include "notedefs.h"


/*
 *   Copyright (c) 1989 by David A. Miller - Unicorn Software
 *   PO Box 3214  Kirkland, WA  98083
 *   ( 206 ) 823-4656  Evening phone
 *                     If I'm not home PLEASE LEAVE YOUR NAME,
 *                     ADDRESS, AND YOUR QUESTION, I will respond
 *                     by mail as quickly as possible.  Sorry but
 *                     I can't afford to return calls.
 *     1 Feb 1989
 *
 *
 *   This library is released as shareware which means you are free
 *   to try it out to see if you wish to use it.  If you do decide to
 *   use it in your programs you may register your copy with the
 *   author.  Registration is $15.00 which entitles you to receive
 *   all library source code upon receipt of the registration fee.
 *
 *   Registration for commercial use of the library is $30.00
 *   and is required before any use of the library routines for
 *   profit.  This registration also comes with full source code.
 *
 *
 *   Registered users may use the routines in programs for distribution
 *   in their object form.  The source code may in no way be provided
 *   in any manner to a third party.
 *
 *   In addition to the full source code all registered users receive
 *   the heartfelt gratitude of the author and his two hungry dogs.
 *
 *   The author may be contacted at the above address for registration.
 *   Upon registration you will be sent a disk containing the
 *   source code for the latest version of the library.
 *
 *   Unicorn Software makes no warranty concerning the suitability
 *   of this software for any purpose and assumes no liability including
 *   but not limited to loss of profit, or other special,
 *   incidental or consequential damage.
 *
 *   In other words we make no claim that the program does anything at
 *   all in spite of the fact this demo program obviously does do
 *   something!
 *
 *                       29 January 1989
 */



/*
		 Treble Clef Scales
	       defined in  notedefs.h

					       G5
    F5 
				       E5
    D5 
			       C5
    B4 
			A4
    G4 
		F4
    E4 
	 D4
    C4    ( Middle C )


	 The notation C4 would be middle C while Cs4 would be
	 middle C sharp.  There is no flat notation so use the
	 lower note sharped.  Always end your note array with
	 FF hex as this is the signal to the library function
	 to terminate the sound generation.

	 It is possible to control the duration of any sound to
	 the millisecond.  All numbers in the below time arrays
	 are the number of milliseconds duration for the above
	 corresponding note arrays.

	 This library intercepts and alters the timer interrupt
	 to accomplish its purpose.  The normal timer interrupt
	 is issued to the rest of the machine at the proper times
	 so all operations should continue as before.  One very
	 important factor is that the sound is begun with a
	 setsound command which has two parameters, the first is
	 the address of a note array and the second is the address
	 of a timing array.  The sound MUST be stopped with an
	 endsound command even if it has already stopped on its
	 own.  This means that each setsound command must be
	 followed by an endsound command.  This is important in
	 order to reset all interrupt vectors properly.  Failure
	 to do this may well result in a machine crash.

	 There are a few internal library variables made available
	 to the user for control purposes.  See the reference to
	 these variables later in the source code for information
	 concerning their names and possible uses.

	 The ability to control duration in millisecond intervals
	 allows the creation of a wide variety of sound effects.
	 A few are provided in this demo to get you started in
	 creating your own.  Have fun!

					  Dave Miller

*/


/* Note that the below arrays always come in pairs and many use the
 * values found in notedefs.h.  There is always an aray of note values
 * and an array of timing values in milliseconds duration.  These two
 * arrays are passed to the setsound() function to control the actual
 * production of sound.
 */


int  intro_tone[] =
		  {
		      43,  48,  52,  55,REST,  55,REST,  55,
		      52,REST,  52,REST,  52,  48,  52,  48,  43,  0x0ff };
int  intro_beat[] =
		  {
		     320, 320, 320, 480,  10, 160,  10, 320,
		     480,  10, 160,  10, 320, 320, 320, 320, 960,      1 };






int greensleves[250] = { Cs4,   E4,  Fs4,  Gs4,  As4,  Gs4,  Fs4,  Ds4,
			  B3,  Cs4,  Ds4,   E4,  Cs4, REST,  Cs4,   C4,
			 Cs4,  Ds4,   C4,  Gs3,  Cs4,   E4,  Fs4,  Gs4,
			 As4,  Gs4,  Fs4,  Ds4,   B3,  Cs4,  Ds4,   E4,
			 Ds4,  Cs4,   C4,  As3,   C4,  Cs4, REST,  Cs4,
			  B4, REST,   B4,  As4,  Gs4,  Fs4,  Ds4,   B3,
			 Cs4,  Ds4,   E4,  Cs4, REST,  Cs4,   C4,  Cs4,
			 Ds4,   C4,  Gs3,   B4, REST,   B4,  As4,  Gs4,
			 Fs4,  Ds4,   B3,  Cs4,  Ds4,   E4,  Ds4,  Cs4,
			  C4,  As3,   C4,  Cs4, REST,  Cs4,
								 0x0ff };
int green_rhythm[250] =
		       { 300,  600,  300,  350,  200,  300,  600,  300,
			 350,  200,  300,  600,  300,   10,  350,  200,
			 300,  600,  300,  600,  300,  600,  300,  350,
			 200,  300,  600,  300,  350,  200,  300,  350,
			 200,  350,  200,  300,  300,  900,   10,  900,
			 600,   10,  300,  300,  300,  600,  300,  350,
			 200,  300,  600,  300,   10,  350,  200,  300,
			 600,  300, 1000, 1000,   10,  350,  200,  300,
			 600,  300,  350,  200,  300,  350,  200,  300,
			 300,  300,  300, 1000,   10,  800,
								     1 };


int auld[ 250 ] =
		       {  D5,    C5,   A4,   A4,   F4,   G4,   F4,   G4,
			  A4,    G4,   F4,   D4,   D4,   C4,   F4,   F4,
			REST,    C4,   F4,   E4,
			  F4,    A4,   G4,   F4,   G4,   A4,   F4, REST,
			  F4,    A4,   C5,
			  D5,    D5, REST,   D5,   C5,   A4, REST,   A4,
			  F4,    G4,   F4,
			  G4,    A4,   F4,   D4, REST,   D4,   C4,   F4,
			  F4,    D5,   C5,   A4, REST,
			  A4,    F4,   G4,   F4,   G4,   D5,   C5,   A4,
			REST,    A4,   C5,
			  D5,    D5, REST,   D5,   C5,   A4, REST,   A4,
			  F4,    G4,   F4,
			  G4,    A4,   F4,   D4, REST,   D4,   C4,   F4,
			  F4,
				  0X0ff };
int auld_rhythm[ 250 ] =
		  {      500,   600,  300,  500,  500,  600,  300,  500,
			 300,   300,  600,  300,  500,  500,  500,  300,
			 300,   500,  600,  300,
			 500,   500,  600,  300,  500,  500,  600,   10,
			 300,   500,  500,
			1000,   600,   10,  600,  650,  300,   10,  600,
			 600,   650,  300,
			 600,   600,  600,  600,   10,  600,  600,  600,
			 900,   600,  650,  300,   10,
			 600,   600,  650,  300,  600,  600,  650,  300,
			  10,   600,  600,
			 900,   600,   10,  500,  650,  300,   10,  600,
			 600,   650,  300,
			 600,   600,  650,  300,   10,  600,   600,  600,
			 300,
						     1 };


int world[] =
		 {
		     D5,   A4,   C5,   A4,   B4,   F4, REST,   F4,
		     A4,   B4,   A4,   B4,   A4,   B4,   A4,   B4,
		     A4,   B4,   A4,
		     B4,   C4, REST,   C4,   A4,   D5,   B4,   C5,
		     A4,   B4,   C4, REST,   C4,   A4,   B4,   A4,
		     B4,   A4,   B4,   A4,   B4,   A4,   B4,   A4,
		     B4,   F4, REST,   F4,   A4,   D5,   A4,
		     C5,   A4,   B4,   F4, REST,   F4,   A4,   B4,
		     A4,   B4,   A4,   B4,   A4,  Cs5,   B4,  As4,
		     B4,
		     F5,   E5, REST,   E5,   B4,   E5,   D5,   C5,
		     B4,  As4,   B4,   D5,   F4,   A4,  Gs4,   A4,
		    As4,
		     B4,  Gs4,   C5,   A4,
		     D5,   C5,   D5,   B4,   C5,   A4, REST,   A4,
							      0X0FF };

int world_rhythm[] =
		  {
		    750,  450,  750,  450,  750,  450,   10,  500,
		    300,  300,  300,  500,  300,  300,  300,  500,
		    300,  300,  300,
		    750,  450,   10,  750,  450,  750,  450,  750,
		    450,  750,  450,   10,  500,  300,  300,  300,
		    500,  300,  300,  300,  500,  300,  300,  300,
		    750,  450,   10,  750,  450,  750,  450,
		    750,  450,  750,  450,   10,  500,  300,  300,
		    500,  300,  300,  300,  300,  300,  300,  300,
		    300,
		    750,  450,   10,  750,  450,  750,  450,  500,
		    300,  300,  300,  750,  450,  500,  300,  300,
		    300,
		    750,  450,  750,  450,
		    750,  300,  300,  300,  300,   450,  10,  450,
								  1 };


/*  Scales */

int ymelody[250] = { C1,  D1, E1, F1, G1, A1, B1,
		     C2,  D2, E2, F2, G2, A2, B2,
		     C3,  D3, E3, F3, G3, A3, B3,
		     C4,  D4, E4, F4, G4, A4, B4,
		     C5,  D5, E5, F5, G5, A5, B5,
		     C6,  D6, E6, F6, G6, A6, B6,
		     C7,  D7, E7, F7, G7, A7, B7,
		     C8,  D8, E8, F8, G8, A8, B8,  0X0FF   };

int ybeat[250]  = { 250, 250, 250, 250, 250, 250, 250,
		    250, 250, 250, 250, 250, 250, 250,
		    250, 250, 250, 250, 250, 250, 250,
		    250, 250, 250, 250, 250, 250, 250,
		    250, 250, 250, 250, 250, 250, 250,
		    250, 250, 250, 250, 250, 250, 250,
		    250, 250, 250, 250, 250, 250, 250,
		    250, 250, 250, 250, 250, 250, 250,
						    1 };

int phasor[ 250 ] = {
		  10, 12, 14, 16, 18, 20, 22, 24, 26, 28,
		  30, 32, 34, 36, 38, 40, 42, 44, 46, 48,
		  50, 52, 54, 56, 58, 60, 62, 64, 66, 68,
		  70, 72, 74, 76, 78, 80, 82, 84, 86, 88,
						      0x0ff };

int phasor_beat[ 250 ] = {
		   5,  5,  5,  5,  5,  5,  5,  5,  5,  5,
		   5,  5,  5,  5,  5,  5,  5,  5,  5,  5,
		   5,  5,  5,  5,  5,  5,  5,  5,  5,  5,
		   5,  5,  5,  5,  5,  5,  5,  5,  5,  5,
							   1 };


int mgun[]      = { 10, 100, 10, 100, 10, 100, 10, 100, 10, 100, 0x0ff };
int mgun_beat[] = { 15, 100, 15, 100, 15, 100, 15, 100, 15, 100,     1 };



int siren[] = {
		  10, 11, 12, 13, 14, 15, 16, 17, 18, 19,
		  20, 21, 22, 23, 24, 25, 26, 27, 28, 29,
		  30, 31, 32, 33, 34, 35, 36, 37, 38, 39,
		  40, 41, 42, 43, 44, 45, 46, 47, 48, 49,
		  50, 51, 52, 53, 54, 55, 56, 57, 58, 59,
		  60, 61, 62, 63, 64, 65, 66, 67, 68, 69,
		  70, 71, 72, 73, 74, 75, 76, 77, 78, 79,
		  80, 79, 78, 77, 76, 75, 74, 73, 72, 71,
		  70, 69, 68, 67, 66, 65, 64, 63, 62, 61,
		  60, 59, 58, 57, 56, 55, 54, 53, 52, 51,
		  50, 49, 48, 47, 46, 45, 44, 43, 42, 41,
		  40, 39, 38, 37, 36, 35, 34, 33, 32, 31,
		  30, 29, 28, 27, 26, 25, 24, 23, 22, 21,
		  20, 19, 18, 17, 16, 15, 14, 13, 12, 11,
		  10, 11, 12, 13, 14, 15, 16, 17, 18, 19,
		  20, 21, 22, 23, 24, 25, 26, 27, 28, 29,
		  30, 31, 32, 33, 34, 35, 36, 37, 38, 39,
		  40, 41, 42, 43, 44, 45, 46, 47, 48, 49,
		  50, 51, 52, 53, 54, 55, 56, 57, 58, 59,
		  60, 61, 62, 63, 64, 65, 66, 67, 68, 69,
		  70, 71, 72, 73, 74, 75, 76, 77, 78, 79,
		  80, 79, 78, 77, 76, 75, 74, 73, 72, 71,
		  70, 69, 68, 67, 66, 65, 64, 63, 62, 61,
		  60, 59, 58, 57, 56, 55, 54, 53, 52, 51,
		  50, 49, 48, 47, 46, 45, 44, 43, 42, 41,
		  40, 39, 38, 37, 36, 35, 34, 33, 32, 31,
		  30, 29, 28, 27, 26, 25, 24, 23, 22, 21,
		  20, 19, 18, 17, 16, 15, 14, 13, 12, 11,
						      0x0ff };

int siren_beat[] = {
		   8,  8,  8,  8,  8,  8,  8,  8,  8,  8,
		   8,  8,  8,  8,  8,  8,  8,  8,  8,  8,
		   8,  8,  8,  8,  8,  8,  8,  8,  8,  8,
		   8,  8,  8,  8,  8,  8,  8,  8,  8,  8,
		   8,  8,  8,  8,  8,  8,  8,  8,  8,  8,
		   8,  8,  8,  8,  8,  8,  8,  8,  8,  8,
		   8,  8,  8,  8,  8,  8,  8,  8,  8,  8,
		   8,  8,  8,  8,  8,  8,  8,  8,  8,  8,
		   8,  8,  8,  8,  8,  8,  8,  8,  8,  8,
		   8,  8,  8,  8,  8,  8,  8,  8,  8,  8,
		   8,  8,  8,  8,  8,  8,  8,  8,  8,  8,
		   8,  8,  8,  8,  8,  8,  8,  8,  8,  8,
		   8,  8,  8,  8,  8,  8,  8,  8,  8,  8,
		   8,  8,  8,  8,  8,  8,  8,  8,  8,  8,
		   8,  8,  8,  8,  8,  8,  8,  8,  8,  8,
		   8,  8,  8,  8,  8,  8,  8,  8,  8,  8,
		   8,  8,  8,  8,  8,  8,  8,  8,  8,  8,
		   8,  8,  8,  8,  8,  8,  8,  8,  8,  8,
		   8,  8,  8,  8,  8,  8,  8,  8,  8,  8,
		   8,  8,  8,  8,  8,  8,  8,  8,  8,  8,
		   8,  8,  8,  8,  8,  8,  8,  8,  8,  8,
		   8,  8,  8,  8,  8,  8,  8,  8,  8,  8,
		   8,  8,  8,  8,  8,  8,  8,  8,  8,  8,
		   8,  8,  8,  8,  8,  8,  8,  8,  8,  8,
		   8,  8,  8,  8,  8,  8,  8,  8,  8,  8,
		   8,  8,  8,  8,  8,  8,  8,  8,  8,  8,
		   8,  8,  8,  8,  8,  8,  8,  8,  8,  8,
		   8,  8,  8,  8,  8,  8,  8,  8,  8,  8,
		   8,  8,  8,  8,  8,  8,  8,  8,  8,  8,
							   1 };

/*  Strauss Horn Concerto No. 1 in E Flat - Opening bars only */
int strauss[] = {
		    48,  52,  55,  52,  57,  55,  52,  48,
		    43,  48,  52,  50,  48,  43,  40,  36,
		    45,  43,  31,                          0x0ff };

int strauss_beat[] = {
		   240,  80, 960, 240,  80, 320, 240,  80,
		   320, 240,  80, 320, 240,  80, 320, 240,
		    80, 640, 640,                              1 };


int love[]  = {
	       A4,  B4,  C5,  D5,  G4,REST,  D4,  G4,  A4,  B4,  C5,  F4,
	     REST,  F4,  G4,  A4,  B4,  G4,REST,  F4,  G4,  F4,  E4,  D4,  A4,
	     REST,  A4,REST,  A4,  B4,  C5,  D5,  G4,REST,  G4,REST,  G4,  A4, B4,  C5, F4,
	     REST,  D4,  F4,  G4,  A4,  B4,  G4,REST,  F4,  G4,  F4,  E4,  D4,REST, D4,REST, A4,

								 0x0ff };

int love_beat[] = {
	      300, 300, 300, 300,1200, 350, 150, 150, 150, 150, 150,1200,
	      300, 150, 150, 225, 150,1200, 225, 150, 150, 150, 150, 150,1200,
	      300, 150,  10, 150, 150, 150, 150,1200, 300, 300,  10, 150,
	      150, 150, 150,1200,
	      300, 150, 150, 150, 150, 150,1200, 300, 150, 150, 150, 150,
	      150,  10,1200, 750, 150,
								   1 };


int up[] = {
	      As4,REST, As4, Ds5,REST, Ds5,  G5,REST,  G5, As4, C5, C5,
	     REST,  C5, Ds5,  F5,  G5, Ds5, Ds5,REST,
	       C5, Ds5,  F5,  G5, Ds5, Ds5,

							      0X0FF };

int up_beat[] = {
	       350,  25, 350, 350,  25, 350, 350,  25, 350, 175, 175,1200,
	       600, 350, 350, 700, 350, 350, 700, 350,
	       175, 175, 700, 350, 350,1200,

		 1 };




int red[ 250 ] = {
		  10, 11, 12, 13, 14, 15, 16, 17, 18, 19,
		  20, 21, 22, 23, 24, 25, 26, 27, 28, 29,
		  30, 31, 32, 33, 34, 35, 36, 37, 38, 39,
		  40, 41, 42, 43, 44, 45, 46, 47, 48, 49,
		  50, 51, 52, 53, 54, 55, 56, 57, 58, 59,
		  60, 61, 62, 63, 64, 65, 66, 67, 68, 69,
		  70, 71, 72, 73, 74, 75, 76, 77, 78, 79,
		  10, 11, 12, 13, 14, 15, 16, 17, 18, 19,
		  20, 21, 22, 23, 24, 25, 26, 27, 28, 29,
		  30, 31, 32, 33, 34, 35, 36, 37, 38, 39,
		  40, 41, 42, 43, 44, 45, 46, 47, 48, 49,
		  50, 51, 52, 53, 54, 55, 56, 57, 58, 59,
		  60, 61, 62, 63, 64, 65, 66, 67, 68, 69,
		  70, 71, 72, 73, 74, 75, 76, 77, 78, 79,
		  10, 11, 12, 13, 14, 15, 16, 17, 18, 19,
		  20, 21, 22, 23, 24, 25, 26, 27, 28, 29,
		  30, 31, 32, 33, 34, 35, 36, 37, 38, 39,
		  40, 41, 42, 43, 44, 45, 46, 47, 48, 49,
		  50, 51, 52, 53, 54, 55, 56, 57, 58, 59,
		  60, 61, 62, 63, 64, 65, 66, 67, 68, 69,
		  70, 71, 72, 73, 74, 75, 76, 77, 78, 79,
						      0x0ff };

int red_beat[ 250 ] = {
		   7,  7,  7,  7,  7,  7,  7,  7,  7,  7,
		   7,  7,  7,  7,  7,  7,  7,  7,  7,  7,
		   7,  7,  7,  7,  7,  7,  7,  7,  7,  7,
		   7,  7,  7,  7,  7,  7,  7,  7,  7,  7,
		   7,  7,  7,  7,  7,  7,  7,  7,  7,  7,
		   7,  7,  7,  7,  7,  7,  7,  7,  7,  7,
		   7,  7,  7,  7,  7,  7,  7,  7,  7,  7,
		   7,  7,  7,  7,  7,  7,  7,  7,  7,  7,
		   7,  7,  7,  7,  7,  7,  7,  7,  7,  7,
		   7,  7,  7,  7,  7,  7,  7,  7,  7,  7,
		   7,  7,  7,  7,  7,  7,  7,  7,  7,  7,
		   7,  7,  7,  7,  7,  7,  7,  7,  7,  7,
		   7,  7,  7,  7,  7,  7,  7,  7,  7,  7,
		   7,  7,  7,  7,  7,  7,  7,  7,  7,  7,
		   7,  7,  7,  7,  7,  7,  7,  7,  7,  7,
		   7,  7,  7,  7,  7,  7,  7,  7,  7,  7,
		   7,  7,  7,  7,  7,  7,  7,  7,  7,  7,
		   7,  7,  7,  7,  7,  7,  7,  7,  7,  7,
		   7,  7,  7,  7,  7,  7,  7,  7,  7,  7,
		   7,  7,  7,  7,  7,  7,  7,  7,  7,  7,
		   7,  7,  7,  7,  7,  7,  7,  7,  7,  7,
							   1 };




		   /* Note that all of the above note arrays end with
		    * the value 0x0ff.  This value is a signal to the
		    * library routines to end sound production.  It
		    * does NOT reset the timer interrupt, this must be
		    * done with an endsound command.
		    */


		    /*  The variables below listed as extern are found
		     *  in the library code.  They have been made accessible
		     *  so they may be used in various control situations.
		     *  Do NOT alter the values in your programs, these
		     *  are internal library values only.
		     */

int sound_on;
int red_flag;

main()
{
	int a;
	int ans;
	extern int cur_note;

	char str[ 100 ];

	sound_on = 1;

	red_flag = 0;

	prepare_intro();
	setsound( intro_tone, intro_beat );
	sound_on = 1;
	animate_intro();
	gets( str );

	while( 1 )
	{
		clr_scr();
		do_it();

		printf( "Which Selection?\n" );
		printf( "  1 - Greensleves         2 - Scales       3 - Auld Lang Syne\n" );
		printf( "  4 - Around the World    5 - Phasor       6 - Machine Gun \n" );
		printf( "  7 - Siren               8 - Strauss      9 - And I Love You So\n" );
		printf( " 10 - Up Where We Belong 11 - Red Alert   12 - Quit Program\n" );


		gets( str );
		ans = atoi( str );

		if ( sound_on )
		{
		   sound_on = 0;
		   endsound();
		}
				   /* The prepare function paints a
				    * treble clef music scale on the
				    * screen.
				    *
				    * The animate function does some
				    * basic text graphics on the screen
				    * while the sound continues in the
				    * background.  Remember you are able
				    * to control the duration of any
				    * sound in millisecond increments.
				    */
		switch ( ans )
		{
			case 1:
				prepare();
				setsound( greensleves, green_rhythm );
				animate();
				sound_on = 1;
				break;

			case 2:
				prepare();
				setsound( ymelody, ybeat );
				animate();
				sound_on = 1;
				break;

			case 3:
				prepare();
				setsound( auld,  auld_rhythm );
				animate();
				sound_on = 1;
				break;


			case 4:
				prepare();
				setsound( world, world_rhythm );
				animate();
				sound_on = 1;
				break;


			case 5:
				setsound( phasor, phasor_beat );
				sound_on = 1;
				break;

			case 6:
				setsound( mgun, mgun_beat );
				sound_on = 1;
				break;

			case 7:
				setsound( siren, siren_beat );
				sound_on = 1;
				break;


			case 8:
				prepare();
				setsound( strauss, strauss_beat );
				animate();
				sound_on = 1;
				break;

			case 9:
				prepare();
				setsound( love, love_beat );
				animate();
				sound_on = 1;
				break;


			case 10:
				prepare();
				setsound( up, up_beat );
				animate();
				sound_on = 1;
				break;


			case 11:
				prepare();
				red_flag = 1;
				setsound( red, red_beat );
				animate();
				red_flag = 0;
				sound_on = 1;
				break;


			case 12 :
				endsound();
				exit( 1 );
				break;

			default :
				break;

		}
	}
	endsound();
}


/*  This function uses a video bios interrupt call to move the
 *  cursor to a specified row and column on the screen.
 */

gotorc( int row, int col )
{
   union REGS ir, or;

   ir.h.bh = ( unsigned char ) 0;   /* video page 0 */
   ir.h.dh = ( unsigned char ) row;
   ir.h.dl = ( unsigned char ) col;
   ir.h.ah = 0x02;
   int86( 0x10, &ir, &or );
   return( 0 );
}



/*  This function places text and a musical scale on the screen.
 */


prepare()
{
   union REGS ir, or;

   clr_scr();

   gotorc( 1, 20 );
   printf( "Unicorn Software Background Sound" );

   gotorc( 2, 19 );
   printf( "Press Any key to return to the menu" );

   gotorc( 21, 6 );
   printf( "All sounds are being produced in the background allowing the" );

   gotorc( 22, 6 );
   printf( "    program to do other things while the sound continues" );

   gotorc( 24, 12 );
   printf( "Imagine what you could do with" );

   gotorc( 24, 43 );
   ir.h.ah = 9;
   ir.h.al = 'G';
   ir.h.bh = 0;
   ir.h.bl = 12;
   ir.x.cx = 1;
   int86( 0x010, &ir, &or );


   gotorc( 24, 45 );
   ir.h.ah = 9;
   ir.h.al = 'r';
   ir.h.bh = 0;
   ir.h.bl = 15;
   ir.x.cx = 1;
   int86( 0x010, &ir, &or );


   gotorc( 24, 47 );
   ir.h.ah = 9;
   ir.h.al = 'a';
   ir.h.bh = 0;
   ir.h.bl = 14;
   ir.x.cx = 1;
   int86( 0x010, &ir, &or );


   gotorc( 24, 49 );
   ir.h.ah = 9;
   ir.h.al = 'p';
   ir.h.bh = 0;
   ir.h.bl = 9;
   ir.x.cx = 1;
   int86( 0x010, &ir, &or );


   gotorc( 24, 51 );
   ir.h.ah = 9;
   ir.h.al = 'h';
   ir.h.bh = 0;
   ir.h.bl = 10;
   ir.x.cx = 1;
   int86( 0x010, &ir, &or );


   gotorc( 24, 53 );
   ir.h.ah = 9;
   ir.h.al = 'i';
   ir.h.bh = 0;
   ir.h.bl = 13;
   ir.x.cx = 1;
   int86( 0x010, &ir, &or );


   gotorc( 24, 55 );
   ir.h.ah = 9;
   ir.h.al = 'c';
   ir.h.bh = 0;
   ir.h.bl = 12;
   ir.x.cx = 1;
   int86( 0x010, &ir, &or );


   gotorc( 24, 57 );
   ir.h.ah = 9;
   ir.h.al = 's';
   ir.h.bh = 0;
   ir.h.bl = 12;
   ir.x.cx = 1;
   int86( 0x010, &ir, &or );


   gotorc( 24, 59 );
   ir.h.ah = 9;
   ir.h.al = '!';
   ir.h.bh = 0;
   ir.h.bl = 15;
   ir.x.cx = 1;
   int86( 0x010, &ir, &or );




   gotorc( 9, 1 );
   draw_line();

   gotorc( 11, 1 );
   draw_line();

   gotorc( 13, 1 );
   draw_line();

   gotorc( 15, 1 );
   draw_line();

   gotorc( 17, 1 );
   draw_line();
}


/*  This function is similar to the prepare function in that it places
 *  the musical scale lines on the screen.  The text placed on the
 *  screen is different.
 */


prepare_intro()
{
   clr_scr();

   gotorc( 1, 20 );
   printf( "Unicorn Software Background Sound" );
   gotorc( 3, 5 );
   printf( "This demo was built using the new background sound functions" );
   gotorc( 4, 5 );
   printf( "found in uc_snd2.lib.  Any sound duration may be controlled in" );
   gotorc( 5, 5 );
   printf( "increments as fine as 1 millisecond.  The fully commented source" );
   gotorc( 6, 5 );
   printf( "code for this demo will provide examples on how to use the library" );
   gotorc( 7, 5 );
   printf( "but after a bit of practice your imagination will be a better guide!" );

   gotorc( 24, 24 );
   printf( "Press ENTER key to continue." );

   gotorc( 9, 1 );
   draw_line();

   gotorc( 11, 1 );
   draw_line();

   gotorc( 13, 1 );
   draw_line();

   gotorc( 15, 1 );
   draw_line();

   gotorc( 17, 1 );
   draw_line();
}




/*  This is similar to the animate function but does NOT paint the
 *  colored bars and an few other things the animate function does.
 */

animate_intro()
{
   extern int cur_note;
   extern int last_note;
   extern int sound_now;
   extern int note_value;

   union REGS ir, or;

   while ( sound_now )
   {

			      /* This is where we position the cursor
			       * and call do_char_att() to paint the
			       * note on the screen.
			       */
      switch ( note_value )
      {
	 case 31 :
	 case 32 :
		    gotorc( 22, cur_note );  /* Position the cursor for */
		    do_char_att();           /* the note and write it   */
		    break;

	 case 33 :
	 case 34 :
		    gotorc( 21, cur_note );
		    do_char_att();
		    break;

	 case 36 :
		    gotorc( 20, cur_note );
		    do_char_att();
		    break;



	 case 37 :
	 case 38 :
		    gotorc( 19, cur_note );
		    do_char_att();
		    break;

	 case 39 :
	 case 40 :
		    gotorc( 18, cur_note );
		    do_char_att();
		    break;

	 case 41 :
		    gotorc( 17, cur_note );
		    do_char_att();
		    break;

	 case 42 :
	 case 43 :
		    gotorc( 16, cur_note );
		    do_char_att();
		    break;

	 case 44 :
	 case 45 :
		    gotorc( 15, cur_note );
		    do_char_att();
		    break;

	 case 46 :
	 case 47 :
		    gotorc( 14, cur_note );
		    do_char_att();
		    break;

	 case 48 :
		    gotorc( 13, cur_note );
		    do_char_att();
		    break;

	 case 49 :
	 case 50 :
		    gotorc( 12, cur_note );
		    do_char_att();
		    break;

	 case 51 :
	 case 52 :
		    gotorc( 11, cur_note );
		    do_char_att();
		    break;

	 case 53 :
		    gotorc( 10, cur_note );
		    do_char_att();
		    break;

	 case 54 :
	 case 55 :
		    gotorc( 9, cur_note );
		    do_char_att();
		    break;

	 case 56 :
	 case 57 :
		    gotorc( 8, cur_note );
		    do_char_att();
		    break;

	 case 58 :
	 case 59 :
		    gotorc( 7, cur_note );
		    do_char_att();
		    break;


	 case 60 :
		    gotorc( 6, cur_note );
		    do_char_att();
		    break;

	 case 61 :
	 case 62 :
		    gotorc( 5, cur_note );
		    do_char_att();
		    break;

      }
      switch( cur_note )
      {
	 case 1 :
	    gotorc( 22, 29 );
	    do_char( 'U' );
	    break;

	 case 2 :
	    gotorc( 22, 30 );
	    do_char( 'n' );
	    break;

	 case 3 :
	    gotorc( 22, 31 );
	    do_char( 'i' );
	    break;

	 case 4 :
	    gotorc( 22, 32 );
	    do_char( 'c' );
	    break;

	 case 5 :
	    gotorc( 22, 33 );
	    do_char( 'o' );
	    break;

	 case 6 :
	    gotorc( 22, 34 );
	    do_char( 'r' );
	    break;

	 case 7 :
	    gotorc( 22, 35 );
	    do_char( 'n' );
	    break;

	 case 8 :
	    gotorc( 22, 37 );
	    do_char( 'S' );
	    break;

	 case 9 :
	    gotorc( 22, 38 );
	    do_char( 'o' );
	    break;

	 case 10 :
	    gotorc( 22, 39 );
	    do_char( 'f' );
	    break;

	 case 11 :
	    gotorc( 22, 40 );
	    do_char( 't' );
	    break;

	 case 12 :
	    gotorc( 22, 41 );
	    do_char( 'w' );
	    break;

	 case 13 :
	    gotorc( 22, 42 );
	    do_char( 'a' );
	    gotorc( 22, 43);
	    do_char( 'r' );
	    gotorc( 22, 44 );
	    do_char( 'e' );
	    break;
      }

      if ( cur_note < 0 )   /* cur_note is set to -1 when music is done */
	 break;
   }
}



/*  Used by the animate_intro() function to write the words
 *  'Unicorn Software' on the bottom of the intro screen in
 *  step with the playing of the notes in the intro song.
 */

do_char( char ch )
{
   union REGS ir, or;

   ir.h.ah = 9;
   ir.h.al = ch;
   ir.h.bh = 0;
   ir.h.bl = 14;
   ir.x.cx = 1;
   int86( 0x010, &ir, &or );
}






/* This function draws a line on the screen using character 196.  It is
 * used to draw the lines for the musical scale.
 */


draw_line()
{
   union REGS ir, or;

   ir.h.ah = 9;
   ir.h.al = '';     /* Character to place on screen */
   ir.h.bh = 0;       /* Video page 0 */
   ir.h.bl = 11;      /* Attribute for character */
   ir.x.cx = 78;      /* Number of characters to write */
   int86( 0x010, &ir, &or );
}



/*  This function places a note symbol ( 0x0d ) on the screen.  Its
 *  horizontal position is determined by the note number in the sequence
 *  and the vertical position is determined by the note value itself.
 *  The actual cursor positioning is done before this call in the large
 *  switch statement below in the function animate().
 */

do_char_att()
{
   union REGS ir, or;

   ir.h.ah = 9;
   ir.h.al = 0x0d;
   ir.h.bh = 0;
   ir.h.bl = 14;
   ir.x.cx = 1;
   int86( 0x010, &ir, &or );
}


/*  Paints a colored bar on the screen.  The color of the bar is
 *  determined by the note_value passed from the library routines.
 *  A lot more could be done with graphics  ( see the Unicorn christmas
 *  card released later this year ) if you wish to try.
 *  There is another Unicorn release with graphics functions.  For
 *  Turbo C users it is called the 'C Tool Box' and for Microsoft users
 *  it is called 'Unicorn Library Version 4.0'.  These may be found on
 *  boards.
 */


animate()
{
   extern int cur_note;
   extern int last_note;
   extern int sound_now;
   extern int note_value;

   union REGS ir, or;

   while ( sound_now )
   {
      if ( red_flag )
      {
	 gotorc( 5, 3 );   /* position the cursor and paint the bar */
	 ir.h.ah = 9;

	 if ( note_value % 2 )
	 {
	    ir.h.al = '';
	    ir.h.bh = 0;
	    ir.h.bl = 4;
	    ir.x.cx = 74;
	    int86( 0x010, &ir, &or );

	    gotorc( 23, 3 );   /* position the cursor and paint the bar */

	    ir.h.al = '';
	    ir.h.bh = 0;
	    ir.h.bl = 4;
	    ir.x.cx = 74;
	    int86( 0x010, &ir, &or );
	 }
	 else
	 {
	    ir.h.al = '';
	    ir.h.bh = 0;
	    ir.h.bl = 12;
	    ir.x.cx = 74;
	    int86( 0x010, &ir, &or );

	    gotorc( 23, 3 );   /* position the cursor and paint the bar */

	    ir.h.al = '';
	    ir.h.bh = 0;
	    ir.h.bl = 12;
	    ir.x.cx = 74;
	    int86( 0x010, &ir, &or );
	 }

      }
      else
      {
	 gotorc( 5, 3 );   /* position the cursor and paint the bar */
	 ir.h.ah = 9;

	 ir.h.al = '';
	 ir.h.bh = 0;
	 ir.h.bl = ( note_value % 15 ) + 1;
	 ir.x.cx = 74;
	 int86( 0x010, &ir, &or );

	 gotorc( 23, 3 );   /* position the cursor and paint the bar */

	 ir.h.al = '';
	 ir.h.bh = 0;
	 ir.h.bl = ( note_value % 15 ) + 1;
	 ir.x.cx = 74;
	 int86( 0x010, &ir, &or );
      }

			      /* This is where we position the cursor
			       * and call do_char_att() to paint the
			       * note on the screen.
			       */
      switch ( note_value )
      {
	 case 31 :
	 case 32 :
		    gotorc( 22, cur_note );  /* Position the cursor for */
		    do_char_att();           /* the note and write it   */
		    break;

	 case 33 :
	 case 34 :
		    gotorc( 21, cur_note );
		    do_char_att();
		    break;

	 case 36 :
		    gotorc( 20, cur_note );
		    do_char_att();
		    break;



	 case 37 :
	 case 38 :
		    gotorc( 19, cur_note );
		    do_char_att();
		    break;

	 case 39 :
	 case 40 :
		    gotorc( 18, cur_note );
		    do_char_att();
		    break;

	 case 41 :
		    gotorc( 17, cur_note );
		    do_char_att();
		    break;

	 case 42 :
	 case 43 :
		    gotorc( 16, cur_note );
		    do_char_att();
		    break;

	 case 44 :
	 case 45 :
		    gotorc( 15, cur_note );
		    do_char_att();
		    break;

	 case 46 :
	 case 47 :
		    gotorc( 14, cur_note );
		    do_char_att();
		    break;

	 case 48 :
		    gotorc( 13, cur_note );
		    do_char_att();
		    break;

	 case 49 :
	 case 50 :
		    gotorc( 12, cur_note );
		    do_char_att();
		    break;

	 case 51 :
	 case 52 :
		    gotorc( 11, cur_note );
		    do_char_att();
		    break;

	 case 53 :
		    gotorc( 10, cur_note );
		    do_char_att();
		    break;

	 case 54 :
	 case 55 :
		    gotorc( 9, cur_note );
		    do_char_att();
		    break;

	 case 56 :
	 case 57 :
		    gotorc( 8, cur_note );
		    do_char_att();
		    break;

	 case 58 :
	 case 59 :
		    gotorc( 7, cur_note );
		    do_char_att();
		    break;


	 case 60 :
		    gotorc( 6, cur_note );
		    do_char_att();
		    break;

	 case 61 :
	 case 62 :
		    gotorc( 5, cur_note );
		    do_char_att();
		    break;

      }
      if ( kbhit() )       /*  Check to see if a key was struck    */
      {                    /*  while the music is playing.  If so  */
	 sound_on = 0;     /*  break and return to the main screen */
	 endsound();
	 break;
      }

      if ( cur_note < 0 )   /* cur_note is set to -1 when music is done */
	 break;
   }
}



/*  Display the main screen
 */

do_it()
{
   int a, b, c;

   printf( "\n\n" );

   printf( "         Background Sound Ŀ\n" );
   printf( "                                                                 \n" );
   printf( "          Unicorn Software is happy to present this upgrade for  \n" );
   printf( "          its previously released background sound routines.     \n" );
   printf( "          This new release has several improvements including    \n" );
   printf( "          the ability to control sound duration to the nearest   \n" );
   printf( "          millisecond.  This fine timing allows production of a  \n" );
   printf( "          variety of sound effects.  Please look at the source   \n" );
   printf( "          code for this demo for details on using the library.   \n" );
   printf( "          This library is released as Shareware by the author    \n" );
   printf( "          please read the source code for details on how to      \n" );
   printf( "          register your copy and receive all source code for     \n" );
   printf( "          the library routines.                                  \n" );
   printf( "                                                                 \n" );
   printf( "         Unicorn Software PO Box 3214 Kirkland, WA  98083 Ĵ\n" );
   printf( "         Phone ( 206 ) 823-4656 \n" );

}



/*  Use the video bios scroll call to clear the screen.
 */


clr_scr()
{
   union REGS regs;

   regs.h.ah = 6;      /* This section scrolls the screen */
   regs.h.al = 0;
   regs.h.ch = 0;
   regs.h.cl = 0;
   regs.h.dl = 80;
   regs.h.dh = 25;
   regs.h.bh = 7;
   int86( 0x10, &regs, &regs );

   regs.h.ah = 2;     /* This section 'Homes' the cursor */
   regs.h.bh = 0;
   regs.h.dh = 0;
   regs.h.dl = 0;
   int86( 0x10, &regs, &regs );
}

